pub enum BlockSizing {
Auto,
Bytes(u64),
Count(u32),
}Expand description
How the creator chooses the source slice size.
Variants
Auto
Choose a size targeting a moderate number of source slices.
Bytes(u64)
Use an explicit source slice size in bytes.
Count(u32)
Choose a source slice size that produces no more than this many slices.