pub enum RecoveryAmount {
Percent(u32),
Count(u32),
}Expand description
How the creator chooses the number of recovery slices.
Variants
Percent(u32)
Derive recovery slices as a percentage of source slices.
Count(u32)
Use an exact recovery-slice count.