pub enum VolumeScheme {
Variable,
Uniform,
Limited,
}Expand description
How recovery slices are divided between recovery volume files.
Variants
Variable
Allocate volume sizes in powers of two, from smallest to largest.
Uniform
Divide recovery slices as evenly as possible.
Limited
Limit each recovery volume to the number of blocks in the largest source file.