pub struct Par2Creator { /* private fields */ }Expand description
High-level PAR2 creator.
Implementations
Sourceimpl Par2Creator
impl Par2Creator
Sourcepub fn new(options: Par2CreatorOptions) -> Self
pub fn new(options: Par2CreatorOptions) -> Self
Construct a creator from explicit source and output options.
Sourcepub fn options(&self) -> &Par2CreatorOptions
pub fn options(&self) -> &Par2CreatorOptions
Borrow the options used by this creator.
Sourcepub fn plan(&self) -> Result<Par2CreatePlan>
pub fn plan(&self) -> Result<Par2CreatePlan>
Validate inputs, hash sources, and allocate packets and output volumes.
Sourcepub fn create(&self, plan: &Par2CreatePlan) -> Result<Par2CreateOutcome>
pub fn create(&self, plan: &Par2CreatePlan) -> Result<Par2CreateOutcome>
Create the outputs described by a validated plan.