pub struct MainPacket {
pub recovery_set_id: RecoverySetId,
pub slice_size: u64,
pub recovery_file_ids: Vec<FileId>,
pub non_recovery_file_ids: Vec<FileId>,
}Expand description
Parsed Main packet.
Contains the slice size and lists of file IDs for recovery and non-recovery files. The recovery_set_id from the header equals the MD5 of this packet’s body.
Fields
recovery_set_id: RecoverySetIdThe recovery set ID (from the packet header).
slice_size: u64Block/slice size in bytes.
recovery_file_ids: Vec<FileId>File IDs of files in the recovery set.
non_recovery_file_ids: Vec<FileId>File IDs of files NOT in the recovery set.
Implementations
Sourceimpl MainPacket
impl MainPacket
Sourcepub fn parse(body: &[u8], recovery_set_id: RecoverySetId) -> Result<Self>
pub fn parse(body: &[u8], recovery_set_id: RecoverySetId) -> Result<Self>
Parse a Main packet from its body bytes (everything after the 64-byte header).