pub struct SettleRead { /* private fields */ }Expand description
A byte range the caller should read to settle an incomplete or ambiguous slice. The range is expressed in the logical file, not a filesystem path.
Implementations
Sourceimpl SettleRead
impl SettleRead