FileRangeReader

Trait FileRangeReader 

pub trait FileRangeReader: Read + Seek { }
Seekable reader used by repair streams that revisit many ranges in one source file. Implementations may return one to avoid reopening per slice.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors