pub struct VerificationMemoryBudget { /* private fields */ }Expand description
A caller-shareable cap for buffered, incomplete slice data.
Whole, aligned slices are checksummed immediately and do not consume this budget. Cloning the budget makes its limit apply across all of the sessions using that clone.
Implementations
Sourceimpl VerificationMemoryBudget
impl VerificationMemoryBudget
Sourcepub fn new(max_buffered_bytes: usize) -> Self
pub fn new(max_buffered_bytes: usize) -> Self
Create a budget shared by any sessions given a clone of this value.
Sourcepub fn max_buffered_bytes(&self) -> usize
pub fn max_buffered_bytes(&self) -> usize
Maximum number of buffered boundary bytes allowed across all users.
Sourcepub fn buffered_bytes(&self) -> usize
pub fn buffered_bytes(&self) -> usize
Number of bytes currently reserved by incomplete slices.
Sourcepub fn available_bytes(&self) -> usize
pub fn available_bytes(&self) -> usize
Number of additional boundary bytes that can currently be buffered.